@@ -18,7 +18,7 @@ class HC(object) :
         stbl : normalize by expected P-values (stbl=True) or observed 
                 P-values (stbl=False). stbl=True was suggested in [2].
                 stbl=False in [1]. 
-        alpha : lower fruction of p-values to use.
+        gamma : lower fruction of p-values to use.
         
     Methods :
     -------
@@ -53,12 +53,12 @@ class HC(object) :
         zMaxStar = self._zz[istar]
         return zMaxStar, self._pvals[istar]
 
-    def HC(self, alpha=0.2) : 
+    def HC(self, gamma=0.2) : 
         """higher criticism score
 
         Args:
         -----
-        'alpha' : lower fraction of P-values to consider
+        'gamma' : lower fraction of P-values to consider
 
         Returns:
         -------
@@ -67,15 +67,15 @@ class HC(object) :
         """
         imin = 0
         imax = np.maximum(imin + 1,
-                        int(np.floor(alpha * self._N + 0.5)))        
+                        int(np.floor(gamma * self._N + 0.5)))        
         return self._calculateHC(imin, imax)
 
-    def HCstar(self, alpha=0.2) :
+    def HCstar(self, gamma=0.2) :
         """sample-adjusted higher criticism score
 
         Args:
         -----
-        'alpha' : lower fraction of P-values to consider
+        'gamma' : lower fraction of P-values to consider
 
         Returns:
         -------
@@ -85,7 +85,7 @@ class HC(object) :
 
         imin = np.argmax(self._pvals > (1-self._EPS)/ self._N)
         imax = np.maximum(imin + 1,
-                        int(np.floor(alpha * self._N + 0.5)))        
+                        int(np.floor(gamma * self._N + 0.5)))        
         return self._calculateHC(imin, imax)
 
     def get_param(self) :
@@ -97,7 +97,7 @@ class HC(object) :
                 }
 
 
-def hc_vals(pv, alpha=0.25, minPv='one_over_n', stbl=True):
+def hc_vals(pv, gamma=0.25, minPv='one_over_n', stbl=True):
     """
     Higher Criticism test (see
     [1] Donoho, D. L. and Jin, J.,
@@ -111,7 +111,7 @@ def hc_vals(pv, alpha=0.25, minPv='one_over_n', stbl=True):
     Args:
     -----
         pv : list of p-values. P-values that are np.nan are exluded.
-        alpha : lower fruction of p-values to use.
+        gamma : lower fruction of p-values to use.
         stbl : use expected p-value ordering (stbl=True) or observed 
                 (stbl=False)
         minPv : integer or string 'one_over_n' (default).
@@ -138,7 +138,7 @@ def hc_vals(pv, alpha=0.25, minPv='one_over_n', stbl=True):
         ps = pv[ps_idx]  #sorted pvals
 
         uu = np.linspace(1 / n, 1-EPS, n)  #expectation of p-values under H0
-        i_lim_up = np.maximum(int(np.floor(alpha * n + 0.5)), 1)
+        i_lim_up = np.maximum(int(np.floor(gamma * n + 0.5)), 1)
 
         ps = ps[:i_lim_up]
         uu = uu[:i_lim_up]
@@ -234,7 +234,7 @@ def binom_test_two_sided_random(x, n, p) :
     prob = np.minimum(p_down + (p_up-p_down)*U, 1)
     return prob * (n != 0) + U * (n == 0)
 
-def two_sample_test(X, Y, alpha=0.25,
+def two_sample_test(X, Y, gamma=0.25,
                 stbl=True, randomize=False):
     """
     Two-sample HC test using binomial P-values. See 
@@ -247,7 +247,7 @@ def two_sample_test(X, Y, alpha=0.25,
     -----
     X, Y : list of integers of equal length -- represnts counts 
             from two samples.
-    alpha : number in (0,1) -- parameter of HC statistics
+    gamma : number in (0,1) -- parameter of HC statistics
     stbl : Boolean -- standardize P-values by i/N or p_{(i)}/N
     randomize : Boolean -- randomized P-valus of not
 
@@ -258,7 +258,7 @@ def two_sample_test(X, Y, alpha=0.25,
     """
     
     pvals = two_sample_pvals(X, Y, randomize=randomize)
-    hc_star, p_thresh = hc_vals(pvals, alpha=alpha, stbl=stbl)
+    hc_star, p_thresh = hc_vals(pvals, gamma=gamma, stbl=stbl)
     
     return hc_star, p_thresh
 
@@ -290,7 +290,7 @@ def two_sample_pvals(c1, c2, randomize=False, sym=False):
 
     return pvals
 
-def two_sample_test_df(X, Y, alpha=0.25,
+def two_sample_test_df(X, Y, gamma=0.25,
                 stbl=True, randomize=False):
     """
     Same as two_sample_test but returns all information for computing
@@ -300,7 +300,7 @@ def two_sample_test_df(X, Y, alpha=0.25,
     Args: 
     -----
     X, Y : lists of integers of equal length
-    alpha : parameter of HC statistic
+    gamma : parameter of HC statistic
     stbl : parameter of HC statistic
     randomize : use randomized or not exact binomial test
 
@@ -341,7 +341,7 @@ def two_sample_test_df(X, Y, alpha=0.25,
         randomize=randomize
         )
     counts['sign'] = np.sign(counts.n1 - (counts.n1 + counts.n2) * counts.p)
-    hc_star, p_val_thresh = hc_vals(counts['pval'], alpha=alpha, stbl=stbl)
+    hc_star, p_val_thresh = hc_vals(counts['pval'], gamma=gamma, stbl=stbl)
     counts['HC'] = hc_star
 
     counts['thresh'] = True
